import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:puma_ui/helpers/alert.dart';

class PumaModalPicker extends StatefulWidget {
  final int selectedIndex;
  final List<String> items;
  final String title;
  final String buttonText;
  final Color buttonColor;
  final double itemExtent;
  final TextStyle? textStyle;
  final TextAlign titleAlign;
  final void Function(String) onDone;

  const PumaModalPicker(
    this.selectedIndex,
    this.items,
    this.title,
    this.onDone,
    this.buttonText, {
    this.buttonColor = Colors.blue,
    this.itemExtent = 32,
    this.titleAlign = TextAlign.left,
    this.textStyle,
  });

  @override
  _PumaModalPickerState createState() => _PumaModalPickerState();
}

class _PumaModalPickerState extends State<PumaModalPicker> {
  String newSelection = "";

  @override
  Widget build(BuildContext context) {
    var picker = CupertinoPicker(
      backgroundColor: Colors.transparent,
      itemExtent: widget.itemExtent,
      scrollController:
          FixedExtentScrollController(initialItem: widget.selectedIndex),
      children: [
        for (var item in widget.items)
          Text(
            item,
            style: widget.textStyle,
          ),
      ],
      onSelectedItemChanged: (value) {
        setState(() {
          newSelection = widget.items[value];
        });
      },
    );

    return AlertDialog(
      title: new Text(
        widget.title,
        textAlign: widget.titleAlign,
      ),
      content: Container(
        height: 80,
        child: picker,
      ),
      actions: [
        getMaterialButton(
          widget.buttonText,
          widget.buttonColor,
          () {
            if (newSelection.isEmpty) {
              newSelection = widget.items[widget.selectedIndex];
            }

            widget.onDone(newSelection);
            Navigator.of(context).pop();
          },
        ),
      ],
    );
  }
}
